function varargout = corr2dgui(varargin)
% CORR2DGUI M-file for corr2dgui.fig
%      
%   Provides graphical user interface above functions corr2d and corr2dhet.
%   Allows user to choose between homo and heterospectral analysis, to look
%   on output spectra and to save them.
%
%
% See also: corr2d, corr2dhet, corr2dgui_switcher
%
%   Copyright (c) 2008 by Tomas Pazderka
%   Revision: 0.90  Date: 28.11. 2008

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @corr2dgui_OpeningFcn, ...
                   'gui_OutputFcn',  @corr2dgui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end
if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before corr2dgui is made visible.
function corr2dgui_OpeningFcn(hObject, eventdata, handles, varargin)

%Sets axes for plotting into a panel.
set(handles.figure1,'CloseRequestFcn',@closedlg);
handles.output = hObject;
handles.graf = axes('Box','on','Units','normalized',...
    'Position',[0.068181818 0.071428571 0.75 0.785714286],'FontUnits','Points','FontSize',12,'Tag','Graf');
xlabel('First spectra');
ylabel('Second spectra');
handles.Data1 = axes('Box','on','Units','normalized',...
    'Position',[0.068181818 0.857142857 0.75 0.095238095],'XTick',[],'YTick',[],'Tag','Data1');
handles.Data2 = axes('Box','on','Units','normalized','Tag','Data2',...
    'Position',[0.8181818181 0.071428571 0.090909091 0.785714286],'XTickMode','manual','XTick',[],'YTick',[]);
handles.side_plots = 1;
handles.mode = 1;
% Settings for interactive zoom - currently disabled - not syncing side
% plots
%h = zoom;
%setAllowAxesZoom(h,handles.Data1,false);
%setAllowAxesZoom(h,handles.Data2,false);
handles.line1 = line(0,0);
handles.line2 = line(0,0);
guidata(hObject, handles);
corr2dgui_switcher('init',handles);

% --- Outputs from this function are returned to the command line.
function varargout = corr2dgui_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

% --- Executes when figure1 is resized.
function corr2dgui_ResizeFcn(hObject, eventdata, handles)

figure_window = get(gcbf,'Position');
set(0,'Units','centimeters');
screen_size = get(0,'ScreenSize');
if (figure_window(1) + figure_window(3)) > screen_size(3)
    figure_window(3) = (screen_size(3) - figure_window(1));
end
if (figure_window(2) + figure_window(4) + 1) > screen_size(4)
    figure_window(4) = (screen_size(4) - figure_window(2));
end
if figure_window(3) < (figure_window(4)+1)
    figure_window(3) = (figure_window(4)+1);
else
    figure_window(4) = (figure_window(3)-1);
end
if figure_window(1) < 0
    figure_window(1) = 1;
end
if figure_window(2) < 0
    figure_window(2) = 1;
end
set(gcbf,'Position',figure_window);
set(0,'Units','pixels');
% --------------------------------------------------------------------
function file_Callback(hObject, eventdata, handles)

% --------------------------------------------------------------------
function mode_Callback(hObject, eventdata, handles)

function homospectral_Callback(hObject, eventdata, handles)
handles.mode = 1;
set(handles.heterospectral,'Checked','off');
set(handles.homospectral,'Checked','on');
guidata(hObject, handles);
corr2dgui_switcher('init',handles);

function heterospectral_Callback(hObject, eventdata, handles)
handles.mode = 2;
set(handles.heterospectral,'Checked','on');
set(handles.homospectral,'Checked','off');
guidata(hObject, handles);
corr2dgui_switcher('init', handles);

% --------------------------------------------------------------------
function load_Callback(hObject, eventdata, handles)

function load1_Callback(hObject, eventdata, handles)
corr2dgui_switcher('load1',handles);

function load2_Callback(hObject, eventdata, handles)
corr2dgui_switcher('load2',handles);

% --------------------------------------------------------------------
function save_Callback(hObject, eventdata, handles)

function save_matrice_Callback(hObject, eventdata, handles)
corr2dgui_switcher('save_matrice',handles);

function save_plot_Callback(hObject, eventdata, handles)
corr2dgui_switcher('save_plot');

% --------------------------------------------------------------------
function treat_matrix_Callback(hObject, eventdata, handles)
treatmatrix;

% --------------------------------------------------------------------
function clear_Callback(hObject, eventdata, handles)
[handles.line1,handles.line2] = corr2dgui_switcher('clear',handles);
guidata(hObject, handles);

% --------------------------------------------------------------------
function Close_Callback(hObject, eventdata, handles)
closedlg;

% --------------------------------------------------------------------
function show_Callback(hObject, eventdata, handles)

function show_syn_Callback(hObject, eventdata, handles)
[handles.line1,handles.line2] = corr2dgui_switcher('show_syn',handles);
guidata(hObject, handles);

function show_asyn_Callback(hObject, eventdata, handles)
[handles.line1,handles.line2] = corr2dgui_switcher('show_asyn',handles);
guidata(hObject, handles);

function Side_plots_Callback(hObject, eventdata, handles)

function show_first_Callback(hObject, eventdata, handles)
handles.side_plots = 1;
guidata(hObject, handles);
[handles.line1,handles.line2] = corr2dgui_switcher('redraw',handles);
guidata(hObject, handles);

function show_last_Callback(hObject, eventdata, handles)
handles.side_plots = 2;
guidata(hObject, handles);
[handles.line1,handles.line2] = corr2dgui_switcher('redraw',handles);
guidata(hObject, handles);

function show_average_Callback(hObject, eventdata, handles)
handles.side_plots = 3;
guidata(hObject, handles);
[handles.line1,handles.line2] = corr2dgui_switcher('redraw',handles);
guidata(hObject, handles);

function show_other_Callback(hObject, eventdata, handles)
handles.side_plots = 4;
guidata(hObject, handles);
[handles.line1,handles.line2] = corr2dgui_switcher('redraw',handles);
guidata(hObject, handles);

% --------------------------------------------------------------------
function tools_Callback(hObject, eventdata, handles)

% --------------------------------------------------------------------
function colormap_Callback(hObject, eventdata, handles)

function Default_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap');
set(handles.Default,'Checked','on');
colormap('default');

function Cold_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap');
set(handles.Cold,'Checked','on');
colormap('cool');

function Hot_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap');
set(handles.Hot,'Checked','on');
colormap('hot');

function HSV_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap')
set(handles.HSV,'Checked','on');
colormap('hsv');

function Spring_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap')
set(handles.Spring,'Checked','on');
colormap('spring');

function Summer_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap')
set(handles.Summer,'Checked','on');
colormap('summer');

function Autumn_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap')
set(handles.Autumn,'Checked','on');
colormap('autumn');

function Winter_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap')
set(handles.Winter,'Checked','on');
colormap('winter');

function Bone_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap')
set(handles.Bone,'Checked','on');
colormap('bone');

function Gray_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap')
set(handles.Gray,'Checked','on');
colormap('gray');

function Copper_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap')
set(handles.Copper,'Checked','on');
colormap('copper');

function Pink_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap')
set(handles.Pink,'Checked','on');
colormap('pink');

function Jet_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap')
set(handles.Jet,'Checked','on');
colormap('jet');

function RedBlue_Callback(hObject, eventdata, handles)
corr2dgui_switcher('colormap');
set(handles.RedBlue,'Checked','on');
RB = zeros(121,3);
for i=1:1:60
    RB(i,3)=1-i/100;
    RB(i+61,1)=0.4+i/100;
end
colormap(RB);

% --------------------------------------------------------------------
function zoom_Callback(hObject, eventdata, handles)
corr2dgui_switcher('zoom',handles);

% --------------------------------------------------------------------
function Colorbar_Callback(hObject, eventdata, handles)
handles.colorbar = corr2dgui_switcher('colorbar_create',handles);
guidata(hObject, handles);

% --------------------------------------------------------------------
function Help1_Callback(hObject, eventdata, handles)


function Help_Callback(hObject, eventdata, handles)
HelpPath = which('Corr2dgui.html');
web(HelpPath); 

% --------------------------------------------------------------------
% --------------------------------------------------------------------

function closedlg(event,str)
selection = questdlg('Are you sure?','Closing GUI','Yes','No','Yes');
switch selection,
   case 'Yes',
    delete(gcf)
   case 'No'
     return
end