function [output1,output2] = corr2dgui_switcher(action,handles)
% EXECUTIVE FUNCTION FOR CORR2DGUI
%   
%   This function is called within the corr2dgui and contains all routines
%   for executing callbacks.
%      
% See also: corr2d, corr2dhet, corr2dgui
%
%   Copyright (c) 2008 by Tomas Pazderka
%   Revision: 0.92  Date: 16.12. 2008

global Data1 Data2 Syn Asyn Scale1 Scale2

switch(action)
    
    %(Re)Initialization of some variables and buttons (seems neccesary
    %on start).
    case 'init',
        Data1 = 0;
        Data2 = 0;
        Syn = 0;
        Asyn = 0;
        Scale1 = 0;
        Scale2 = 0;
        A = {'load2','show_syn','show_asyn','save_matrice','save_plot','Side_plots'};
        n = size(A);
        for i=1:n(2)
            InitHandle = findobj(gcbf,'Tag',A{i});
            set(InitHandle,'Enable','off');
        end
        set(handles.show_syn,'Checked','off');
        set(handles.show_asyn,'Checked','off');
        set(handles.show_first,'Checked','off');
        set(handles.show_last,'Checked','off');
        set(handles.show_average,'Checked','off');
        set(handles.show_other,'Checked','off');
    
    %Opens a dialog box and loads first spectra. Also activates other
    %menu items if needed or calls correlation.    
    case 'load1',
        [FileName,PathName] = uigetfile({'*.txt;*.prn','ASCII spectra (*.prn, *.txt)'},...
            'Select first spectra');
        if isequal(FileName,0) || isequal(PathName,0)
            return
        end
        Data1 = load(strcat(PathName,FileName));
        if isequal(handles.mode,1)
            corr2dgui_switcher('correlation',handles);
        else
            set(handles.load2,'Enable','on');
        end
    %Opens a dialog box and loads second spectra (if needed). Calls
    %correlation.            
    case 'load2',
        [FileName,PathName] = uigetfile({'*.txt;*.prn','ASCII spectra (*.prn, *.txt)'},...
            'Select second spectra');
        if isequal(FileName,0) || isequal(PathName,0)
            return
        end
        Data2 = load(strcat(PathName,FileName));
        corr2dgui_switcher('correlation',handles);
        
    %Calculate correlation spectra. See corr2d and corr2dhet for
    %details. Activate other menu items.
    case 'correlation',
        if isequal(handles.mode,1)
            [Syn,Asyn] = corr2d(Data1);
            Scale1 = Data1(:,1);
            Scale2 = Scale1;
        else
            [Syn,Asyn] = corr2dhet(Data1,Data2);
            Scale1 = Data1(:,1);
            Scale2 = Data2(:,1);
        end
        set(handles.show_syn,'Enable','on');
        set(handles.show_asyn,'Enable','on');
        set(handles.save_matrice,'Enable','on');

    %Saves output of corr2d(het) into text file, where first two
    %columns are scales.        
    case 'save_matrice'
        Syn1(:,1) = Scale1;
        Asyn1(:,1) = Scale1;
        Syn1(:,2) = Scale2;
        Asyn1(:,2) = Scale2;
        n = size(Syn);
        for i=1:n(2)
            Syn1(:,i+2) = Syn(:,i);
            Asyn1(:,i+2) = Asyn(:,i);
        end
        [FileName,PathName] = uiputfile({'*.txt','Text file (*.txt)'},...
            'Save both output spectra.');
        if isequal(FileName,0) || isequal(PathName,0)
            return
        end
        [PathName,FileName] = fileparts(fullfile(PathName,FileName));
        save(fullfile(PathName,strcat(FileName,'_synch','.txt')),'Syn1','-ascii');
        save(fullfile(PathName,strcat(FileName,'_asynch','.txt')),'Asyn1','-ascii');

    %Saves current plot into a figure.        
    case 'save_plot'
        [FileName, PathName] = uiputfile({'*.jpg','Compressed picture (*.jpg)';...
            '*.bmp','Windows bitmap (*.bmp)';'*.tiff','Uncompressed image (*.tiff)';...
            '*.png','Portable Network graphics (*.png)';'*.pgm','Portable Graymap (*.pgm)';...
            '*.gif','Graphics interchange format (*.gif)'},'Save current plot as');
        if isequal(FileName,0) || isequal(PathName,0)
            return
        end
        I = getframe(gcf);
        imwrite(I.cdata,fullfile(PathName,FileName));


    %Plots asynchronous spectra into the GUI.        
    case 'show_asyn',
        axes(handles.graf);
        contour(Scale2,Scale1,Asyn,30);
        xlabel('First spectra');
        ylabel('Second spectra');        
        [output1,output2] = corr2dgui_switcher('redraw',handles);
        set(handles.save_plot,'Enable','on');
        set(handles.Side_plots,'Enable','on');
        set(handles.show_syn,'Checked','off');
        set(handles.show_asyn,'Checked','on');
        set(handles.Colorbar,'Checked','off');

    %Plots synchronous spectra into the GUI.        
    case 'show_syn',
        axes(handles.graf);
        contour(Scale2,Scale1,Syn,30);
        xlabel('First spectra');
        ylabel('Second spectra');       
        [output1,output2] = corr2dgui_switcher('redraw',handles);
        set(handles.save_plot,'Enable','on');
        set(handles.Side_plots,'Enable','on');
        set(handles.show_syn,'Checked','on');
        set(handles.show_asyn,'Checked','off');
        set(handles.Colorbar,'Checked','off');

    %Plots side spectra based on users choice        
    case 'redraw',
        test = handles.side_plots;
        X1 = Scale1;
        n = size(Data1);
        set(handles.show_first,'Checked','off');
        set(handles.show_last,'Checked','off');
        set(handles.show_average,'Checked','off');
        set(handles.show_other,'Checked','off');
        switch(test)
            case 1
                set(handles.show_first,'Checked','on');
                Y1 = Data1(:,2);
                if isequal(handles.mode,1)
                    X2 = X1;
                    Y2 = Y1;
                else
                    X2 = Scale2;
                    Y2 = Data2(:,2);
                end
            case 2
                set(handles.show_last,'Checked','on');
                Y1 = Data1(:,n(2));
                if isequal(handles.mode,1)
                    X2 = X1;
                    Y2 = Y1;
                else
                    X2 = Scale2;
                    Y2 = Data2(:,n(2));
                end
            case 3
                set(handles.show_average,'Checked','on');
                Y1 = zeros(n(1),1);
                for i=2:1:n(2)
                    Y1 = Y1 + Data1(:,i);
                end
                Y1 = Y1 / (n(2)-1);
                if isequal(handles.mode,1)
                    X2 = X1;
                    Y2 = Y1;
                else
                    X2 = Scale2;
                    Y2 = zeros(n(1),1);
                    for i=2:1:n(2)
                        Y2 = Y2 + Data2(:,i);
                    end
                    Y2 = Y2 / (n(2)-1);
                end
            case 4
                set(handles.show_other,'Checked','on');
                temp = inputdlg('Enter index of spectra (note: first two are scale...)',...
                    'Selecting side plot spectra',1,{'3'},'on');
                temp = str2double(temp(1));
                while (temp < 3 || temp > n(2))
                    h = errordlg('Index of spectra out of range!','Bad index');
                    uiwait(h);
                    temp = inputdlg('Enter index of spectra (note: first two are scale...)',...
                        'Selecting side plot spectra',1,{'3'},'on');
                    temp = str2double(temp(1));
                end
                Y1 = Data1(:,temp);
                if isequal(handles.mode,1)
                    X2 = X1;
                    Y2 = Y1;
                else
                    X2 = Scale2;
                    Y2 = Data2(:,temp);
                end
                
        end
        temp = size (X1);
        if X1(1) < X1(temp(1))
            Xlim(1) = X1(1);
            Xlim(2) = X1(temp(1));
        else
            Xlim(1) = X1(temp(1));
            Xlim(2) = X1(1);
        end
        axes(handles.Data2);
        delete(handles.line1);
        output1 = line(Y1,X1);
        set(handles.Data2,'Ylim',Xlim);
        temp = size (X2);
        if X2(1) < X2(temp(1))
            Xlim(1) = X2(1);
            Xlim(2) = X2(temp(1));
        else
            Xlim(1) = X2(temp(1));
            Xlim(2) = X2(1);
        end
        set(handles.Data1,'Xlim',Xlim);
        delete(handles.line2);
        axes(handles.Data1);
        output2 = line(X2,Y2);
        
    %Clearing checkings on colormap menu items       
    case 'colormap',
        A={'Default','Cold','Hot','RedBlue','HSV','Spring','Summer','Autumn',...
            'Winter','Gray','Bone','Copper','Pink','Jet'};
        n = size(A);
        for i=1:n(2)
            InitHandle = findobj(gcbf,'Tag',A{i});
            set(InitHandle,'Checked','off');
        end

    %Clearing all data in the workspace        
    case 'clear',
        selection = questdlg('Are you sure?','Clearing all data','Yes','No','Yes');
        switch selection,
            case 'Yes',
            corr2dgui_switcher('init',handles);
            axes(handles.Data1);
            delete(handles.line1);
            output1 = line(0,0);
            axes(handles.Data2);
            delete(handles.line2);
            output2 = line(0,0);
            axes(handles.graf);
            xlabel('First spectra');
            ylabel('Second spectra');
            contour(zeros(1));
            case 'No'
                return
        end

	%Zoom in data for selected ranges.        
    case 'zoom',
        temp = inputdlg({'X min','X max','Y min','Y max'},'Set range fo zoom',...
            1,{'','','',''},'on');
        if isequal(size(temp,1),4)
            temp = str2double(temp);
            Xlim(1) = temp(1);
            Xlim(2) = temp(2);
            Ylim(1) = temp(3);
            Ylim(2) = temp(4);
            set(handles.graf,'XLim',Xlim,'YLim',Ylim);
            set(handles.Data1,'XLim',Xlim);
            set(handles.Data2,'YLim',Ylim);
        else
            return
        end
% Interactive zooming
%         if isequal(get(handles.zoom,'Checked'),'on')
%             set(handles.zoom,'Checked','off');
%             zoom off;
%         else
%             set(handles.zoom,'Checked','on');
%             zoom on;
%         end

	%Creates/deletes a colorbar on the side of the plot.        
    case 'colorbar_create'
        if isequal(get(handles.Colorbar,'Checked'),'on')
            delete(handles.colorbar);
            set(handles.Colorbar,'Checked','off');
            output1 = 0;
        else
            %output1 = axes('Parent',handles.panel,'Units','normalized',...
    %'Position',[0.931818182 0.071428571 0.022727273 0.785714286],'Box','on','XTick',[],'YTick',[]);
            set(handles.Colorbar,'Checked','on');
            output1 = colorbar('peer',handles.graf,'Position',[0.931818182 0.071428571 0.022727273 0.785714286]);
        end
end